========
Examples
========

This folder includes code snippets, mostly taken from the tutorials. Please see the tutorials (in ``docs/tutorials``) for further information. In addition, it contains two more specific examples:


Cruise ship
~~~~~~~~~~~

An early application of Covasim to the Diamond Princess cruise ship.


Calibration
~~~~~~~~~~~

Examples of how to calibrate simulations, including `Optuna`_ (also covered in the tutorial) and `Weights and Biases`_.

.. _Optuna: https://optuna.org/
.. _Weights and Biases: https://www.wandb.com/